==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d1/ddf/rail__type_8h.js <==
var rail__type_8h =
[
    [ "EnumPropsT< RailType >", "d6/df3/structEnumPropsT_3_01RailType_01_4.html", null ],
    [ "RailTypeByte", "d1/ddf/rail__type_8h.html#a25c26dc34c2603ca5a8144d0f8e41d07", null ],
    [ "RailTypeLabel", "d1/ddf/rail__type_8h.html#a3155d7b69162cf75a05e2e60a9a517b3", null ],
    [ "RailType", "d1/ddf/rail__type_8h.html#ac69a1d03decd0bd8b1055cc537addb06", [
      [ "RAILTYPE_BEGIN", "d1/ddf/rail__type_8h.html#ac69a1d03decd0bd8b1055cc537addb06a08b0dec1ade3fd792196a53fd5bd6f43", null ],
      [ "RAILTYPE_RAIL", "d1/ddf/rail__type_8h.html#ac69a1d03decd0bd8b1055cc537addb06add90d561c5b13f544b61a88aa17f524e", null ],
      [ "RAILTYPE_ELECTRIC", "d1/ddf/rail__type_8h.html#ac69a1d03decd0bd8b1055cc537addb06add02081f0df9c6ca3c63997e23287211", null ],
      [ "RAILTYPE_MONO", "d1/ddf/rail__type_8h.html#ac69a1d03decd0bd8b1055cc537addb06aa28a101fda5a7553e3e3756f795e2901", null ],
      [ "RAILTYPE_MAGLEV", "d1/ddf/rail__type_8h.html#ac69a1d03decd0bd8b1055cc537addb06ae815f01bce0f94a716b8dec069d4217d", null ],
      [ "RAILTYPE_END", "d1/ddf/rail__type_8h.html#ac69a1d03decd0bd8b1055cc537addb06a0f385b91526e771cc46366b10455c2de", null ],
      [ "INVALID_RAILTYPE", "d1/ddf/rail__type_8h.html#ac69a1d03decd0bd8b1055cc537addb06ab78e54ad96f65bd590ef8238724bbeba", null ],
      [ "DEF_RAILTYPE_FIRST", "d1/ddf/rail__type_8h.html#ac69a1d03decd0bd8b1055cc537addb06aa348688c5a2fa1e7ffa55d230b18e0b7", null ],
      [ "DEF_RAILTYPE_LAST", "d1/ddf/rail__type_8h.html#ac69a1d03decd0bd8b1055cc537addb06a48e6488506fb769e2ba1daf25b2e935d", null ],
      [ "DEF_RAILTYPE_MOST_USED", "d1/ddf/rail__type_8h.html#ac69a1d03decd0bd8b1055cc537addb06a7473dd482f0af9ffe11f323f0cfd03fe", null ]
    ] ],
    [ "RailTypes", "d1/ddf/rail__type_8h.html#a5ecfa5ca4aee941498850f443c0630ce", [
      [ "RAILTYPES_NONE", "d1/ddf/rail__type_8h.html#a5ecfa5ca4aee941498850f443c0630ceade20b3116bd8e7231ca9e8e0ac6ff86c", null ],
      [ "RAILTYPES_RAIL", "d1/ddf/rail__type_8h.html#a5ecfa5ca4aee941498850f443c0630ceab7ca67eabddde4a9a528026bfc5a6450", null ],
      [ "RAILTYPES_ELECTRIC", "d1/ddf/rail__type_8h.html#a5ecfa5ca4aee941498850f443c0630cea8192bd6bfe85cd9c315c91d208bf0b5a", null ],
      [ "RAILTYPES_MONO", "d1/ddf/rail__type_8h.html#a5ecfa5ca4aee941498850f443c0630ceae190edf41da0b0c8c10e32fa2937d39f", null ],
      [ "RAILTYPES_MAGLEV", "d1/ddf/rail__type_8h.html#a5ecfa5ca4aee941498850f443c0630ceab50bfd5a487383f9a9872a8092c6031a", null ],
      [ "INVALID_RAILTYPES", "d1/ddf/rail__type_8h.html#a5ecfa5ca4aee941498850f443c0630ceaaf61c57c1e7b64ee15a184da1c108b82", null ]
    ] ],
    [ "RAILTYPE_ELECTRIC_LABEL", "d1/ddf/rail__type_8h.html#ac2d93d2f173ff9b5b66b90ce1dc3fe2a", null ],
    [ "RAILTYPE_MAGLEV_LABEL", "d1/ddf/rail__type_8h.html#a7651b5b7e29f4916b2bff8a3e68ec736", null ],
    [ "RAILTYPE_MONO_LABEL", "d1/ddf/rail__type_8h.html#a9bcfd49577191e8c2ca2d95d854e7e30", null ],
    [ "RAILTYPE_RAIL_LABEL", "d1/ddf/rail__type_8h.html#a9e017252eb01bce0357eb3de0110510d", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d1/ddf/rail__type_8h.js <==
var rail__type_8h =
[
    [ "EnumPropsT< RailType >", "d6/df3/structEnumPropsT_3_01RailType_01_4.html", null ],
    [ "RailTypeLabel", "d1/ddf/rail__type_8h.html#a3155d7b69162cf75a05e2e60a9a517b3", null ],
    [ "RailType", "d1/ddf/rail__type_8h.html#a88ebed64deb1833cc5e4e234ec3f200f", [
      [ "RAILTYPE_BEGIN", "d1/ddf/rail__type_8h.html#a88ebed64deb1833cc5e4e234ec3f200fa08b0dec1ade3fd792196a53fd5bd6f43", null ],
      [ "RAILTYPE_RAIL", "d1/ddf/rail__type_8h.html#a88ebed64deb1833cc5e4e234ec3f200fadd90d561c5b13f544b61a88aa17f524e", null ],
      [ "RAILTYPE_ELECTRIC", "d1/ddf/rail__type_8h.html#a88ebed64deb1833cc5e4e234ec3f200fadd02081f0df9c6ca3c63997e23287211", null ],
      [ "RAILTYPE_MONO", "d1/ddf/rail__type_8h.html#a88ebed64deb1833cc5e4e234ec3f200faa28a101fda5a7553e3e3756f795e2901", null ],
      [ "RAILTYPE_MAGLEV", "d1/ddf/rail__type_8h.html#a88ebed64deb1833cc5e4e234ec3f200fae815f01bce0f94a716b8dec069d4217d", null ],
      [ "RAILTYPE_END", "d1/ddf/rail__type_8h.html#a88ebed64deb1833cc5e4e234ec3f200fa0f385b91526e771cc46366b10455c2de", null ],
      [ "INVALID_RAILTYPE", "d1/ddf/rail__type_8h.html#a88ebed64deb1833cc5e4e234ec3f200fab78e54ad96f65bd590ef8238724bbeba", null ]
    ] ],
    [ "RailTypes", "d1/ddf/rail__type_8h.html#a5ecfa5ca4aee941498850f443c0630ce", [
      [ "RAILTYPES_NONE", "d1/ddf/rail__type_8h.html#a5ecfa5ca4aee941498850f443c0630ceade20b3116bd8e7231ca9e8e0ac6ff86c", null ],
      [ "RAILTYPES_RAIL", "d1/ddf/rail__type_8h.html#a5ecfa5ca4aee941498850f443c0630ceab7ca67eabddde4a9a528026bfc5a6450", null ],
      [ "RAILTYPES_ELECTRIC", "d1/ddf/rail__type_8h.html#a5ecfa5ca4aee941498850f443c0630cea8192bd6bfe85cd9c315c91d208bf0b5a", null ],
      [ "RAILTYPES_MONO", "d1/ddf/rail__type_8h.html#a5ecfa5ca4aee941498850f443c0630ceae190edf41da0b0c8c10e32fa2937d39f", null ],
      [ "RAILTYPES_MAGLEV", "d1/ddf/rail__type_8h.html#a5ecfa5ca4aee941498850f443c0630ceab50bfd5a487383f9a9872a8092c6031a", null ],
      [ "INVALID_RAILTYPES", "d1/ddf/rail__type_8h.html#a5ecfa5ca4aee941498850f443c0630ceaaf61c57c1e7b64ee15a184da1c108b82", null ]
    ] ],
    [ "RAILTYPE_ELECTRIC_LABEL", "d1/ddf/rail__type_8h.html#ac2d93d2f173ff9b5b66b90ce1dc3fe2a", null ],
    [ "RAILTYPE_MAGLEV_LABEL", "d1/ddf/rail__type_8h.html#a7651b5b7e29f4916b2bff8a3e68ec736", null ],
    [ "RAILTYPE_MONO_LABEL", "d1/ddf/rail__type_8h.html#a9bcfd49577191e8c2ca2d95d854e7e30", null ],
    [ "RAILTYPE_RAIL_LABEL", "d1/ddf/rail__type_8h.html#a9e017252eb01bce0357eb3de0110510d", null ]
];
